@@ -175,7 +175,7 @@ c                        the last / is needed.
 c              This is to form  Cmsp
           call chncol(pj2, tg, a, ntp, icon)
 
-          call rnd1i(InitRn)     ! random number init.
+          call rnd1i(InitRN)     ! random number init.
 c             fix model by seeing the proj. energy.
           call cfixModel(pj)
           if(cms) then
@@ -219,15 +219,15 @@ c             fix model by seeing the proj. energy.
 c/////////////
              tgtA = ia
              tgtZ = iz
-             call cxsecGheisha(pj, tgtA, tgtZ, xs)
-            write(0,*) xs
+c             call cxsecGheisha(pj, tgtA, tgtZ, xs)
+c            write(0,*) xs
 c
 c
-            call ctotx(pj, tgtA,  xs)
+c            call ctotx(pj, tgtA,  xs)
 
-            write(0,*) xs
-            call cprotonAXsec(tgtA, pj.fm.p(4)-pj.mass, xs)
-            write(0,*) xs
+c            write(0,*) xs
+c            call cprotonAXsec(tgtA, pj.fm.p(4)-pj.mass, xs)
+c            write(0,*) xs
 
 c////////////
 
