@@ -20,8 +20,8 @@ c             switch to the random number generator 1
          call rndsw(jold, 1)
          if(Job .ne. 'newflesh') then
 c              for newflesh, these are managed in chookBgEvent
-            EventsInTheRun = EventsInTheRun + 1
-            EventNo = EventNo + 1
+cc            EventsInTheRun = EventsInTheRun + 1  ! moved to cmkIncident.f
+cc            EventNo = EventNo + 1                ! from  v6.25
             if(RefreshIR) then
 c               special case. init for ir of this event is
 c               read from 14 which should have been opend by the
@@ -35,19 +35,19 @@ c                get random seed at skelton making
                if( jeof .ne. 0 ) goto 10
 c                 reset the seed.
                call rnd1r(SeedSave)
-            else
-c                 save the initial seed of random number
-               call rnd1s(SeedSave)
-               if(Job .eq. ' ' .and. SeedFile .ne. ' ') then
-                  call cwriteSeed
-               endif
-            endif          
-
+            endif
             call cmkIncident(incident, fin)
             if(fin .ne. 0) goto 10 ! all including cuoffed end
+c                 save the initial seed of random number
+            call rnd1s(SeedSave)
+            if(Job .eq. ' ' .and. SeedFile .ne. ' ') then
+               call cwriteSeed
+            endif
+
             call ciniTracking( incident ) ! init for tracking each event
             call cinitStack
             call cpush(incident)
+            call cforceSSP
          endif
 
          call chookBgEvent    ! user hook for each event beginning
@@ -62,3 +62,39 @@ c              next is managed by chookEnEven if new flesh
       enddo
  10   continue
       end
+      subroutine  cforceSSP
+#include "Ztrack.h"
+#include "Zevhnp.h"
+#include "Zcode.h"
+#include "Zmass.h"
+
+      record /track/inci, pj
+      record /coord/angle
+
+      call cqIncident(inci, angle)
+c      write(0,*)'  Intmodel=', IntModel
+      if(inci.p.code .eq. kgnuc .and. inci.p.subcode .gt. 18
+     *     .and. IntModel(1:9) .eq. '"dpmjet3"' ) then
+c         write(0,*) ' reset stack'
+         call cinitStack
+         pj = inci
+         do i = 1, 4
+            pj.p.fm.p(i) = inci.p.fm.p(i)/inci.p.subcode
+         enddo
+         pj.p.mass = masp
+         pj.p.code = knuc
+         pj.p.subcode = -1
+         pj.p.charge = 1
+
+         do i = 1, inci.p.charge
+            call cpush(pj)
+         enddo
+         pj.p.mass = masn
+         pj.p.charge = 0
+         do i = 1, inci.p.subcode - inci.p.charge
+            call cpush(pj)
+         enddo
+            
+      endif
+      end
+
