@@ -47,7 +47,9 @@ c            default trace output is requested. Open disk file
      *         EventNo
          call kseblk(tracefile, ' ', leng)
          call copenfw(TraceDev, tracefile(1:leng), icon)
-         if(icon  .ne. 0) stop
+         if(icon .ne. 0) then
+            call cerrorMsg('tracefile couldnot be opened',0)
+         endif
       elseif(Trace .gt. 60 .and. Trace .lt. 100 .or.
      *       Trace .gt. 160 .and. Trace .lt. 200) then
          call cputCerenkovS     ! cerenkov output header for each event
